==> option-annotations-2.6.0-sources.jar: io/dekorate/option/config/VcsConfigBuilder.java <==
package io.dekorate.option.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class VcsConfigBuilder extends io.dekorate.option.config.VcsConfigFluentImpl<io.dekorate.option.config.VcsConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.option.config.VcsConfig,io.dekorate.option.config.VcsConfigBuilder>{
  public VcsConfigBuilder() {
    this(false);
  }
  public VcsConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new VcsConfig(), validationEnabled);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new VcsConfig(), validationEnabled);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfigFluent<?> fluent,io.dekorate.option.config.VcsConfig instance) {
    this(fluent, instance, false);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfigFluent<?> fluent,io.dekorate.option.config.VcsConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withRemote(instance.getRemote()); 
    fluent.withHttpsPreferred(instance.getHttpsPreferred()); 
    this.validationEnabled = validationEnabled; 
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfig instance) {
    this(instance,false);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withRemote(instance.getRemote()); 
    this.withHttpsPreferred(instance.getHttpsPreferred()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.option.config.VcsConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.option.config.EditableVcsConfig build() {
    EditableVcsConfig buildable = new EditableVcsConfig(fluent.getProject(),fluent.getAttributes(),fluent.getRemote(),fluent.getHttpsPreferred());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VcsConfigBuilder that = (VcsConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> option-annotations-2.11.1-sources.jar: io/dekorate/option/config/VcsConfigBuilder.java <==
package io.dekorate.option.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class VcsConfigBuilder extends VcsConfigFluentImpl<VcsConfigBuilder> implements VisitableBuilder<io.dekorate.option.config.VcsConfig,VcsConfigBuilder>{
  public VcsConfigBuilder() {
    this(false);
  }
  public VcsConfigBuilder(Boolean validationEnabled) {
    this(new VcsConfig(), validationEnabled);
  }
  public VcsConfigBuilder(VcsConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new VcsConfig(), validationEnabled);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfigFluent<?> fluent,io.dekorate.option.config.VcsConfig instance) {
    this(fluent, instance, false);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfigFluent<?> fluent,io.dekorate.option.config.VcsConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withRemote(instance.getRemote()); 
    fluent.withHttpsPreferred(instance.getHttpsPreferred()); 
    this.validationEnabled = validationEnabled; 
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfig instance) {
    this(instance,false);
  }
  public VcsConfigBuilder(io.dekorate.option.config.VcsConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withRemote(instance.getRemote()); 
    this.withHttpsPreferred(instance.getHttpsPreferred()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.option.config.VcsConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableVcsConfig build() {
    EditableVcsConfig buildable = new EditableVcsConfig(fluent.getProject(),fluent.getAttributes(),fluent.getRemote(),fluent.getHttpsPreferred());
    return buildable;
  }
  
}
